==> haskell-pem-0.2.4-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-KYLr6DV0hSA3vIwlY7BSsP
key: pem-0.2.4-KYLr6DV0hSA3vIwlY7BSsP
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: b3b848b113465a68d82abec50deb5012
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.6.1/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-KYLr6DV0hSA3vIwlY7BSsP
depends:
    base-4.12.0.0 basement-0.0.8-LdnmevtSRu4FZXxmMQJlGY
    bytestring-0.10.8.2 memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pem
version: 0.2.4
id: pem-0.2.4-bp5NswTNLqL9Lbd4SUIVc
key: pem-0.2.4-bp5NswTNLqL9Lbd4SUIVc
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-pem
synopsis: Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description
category: Data
abi: 51e49f159cfe7fab613ad9f7130d4b66
exposed: True
exposed-modules:
    Data.PEM
hidden-modules: Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs: /usr/lib/ghc-8.6.1/site-local/pem-0.2.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pem
hs-libraries: HSpem-0.2.4-bp5NswTNLqL9Lbd4SUIVc
depends:
    base-4.12.0.0 basement-0.0.8-LdnmevtSRu4FZXxmMQJlGY
    bytestring-0.10.8.2 memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
haddock-interfaces: /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html: /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
